import { DocumentColorParams, DocumentFormattingParams, DocumentLinkParams, IConnection, TextDocumentPositionParams, ColorPresentationParams, InitializeParams, ServerCapabilities, CancellationToken } from 'vscode-languageserver';
import { ColorInformation, CompletionItem, Definition, Diagnostic, DocumentHighlight, DocumentLink, DocumentSymbolParams, Location, SignatureHelp, SymbolInformation, TextDocument, TextEdit } from 'vscode-languageserver-types';
export declare class VLS {
    private lspConnection;
    private workspacePath;
    private documentService;
    private vueInfoService;
    private dependencyService;
    private languageModes;
    private pendingValidationRequests;
    private validationDelayMs;
    private validation;
    constructor(lspConnection: IConnection);
    init(params: InitializeParams): Promise<{
        capabilities: {};
    } | undefined>;
    listen(): void;
    private setupConfigListeners;
    private setupLSPHandlers;
    private setupFileChangeListeners;
    configure(config: any): void;
    /**
     * Custom Notifications
     */
    displayInfoMessage(msg: string): void;
    displayWarningMessage(msg: string): void;
    displayErrorMessage(msg: string): void;
    /**
     * Language Features
     */
    onDocumentFormatting({ textDocument, options }: DocumentFormattingParams): TextEdit[];
    onCompletion({ textDocument, position }: TextDocumentPositionParams): import("vscode-languageserver-types").CompletionList;
    onCompletionResolve(item: CompletionItem): CompletionItem;
    onHover({ textDocument, position }: TextDocumentPositionParams): import("vscode-languageserver-types").Hover | {
        contents: never[];
    };
    onDocumentHighlight({ textDocument, position }: TextDocumentPositionParams): DocumentHighlight[];
    onDefinition({ textDocument, position }: TextDocumentPositionParams): Definition;
    onReferences({ textDocument, position }: TextDocumentPositionParams): Location[];
    onDocumentLinks({ textDocument }: DocumentLinkParams): DocumentLink[];
    onDocumentSymbol({ textDocument }: DocumentSymbolParams, token: CancellationToken): SymbolInformation[];
    onDocumentColors({ textDocument }: DocumentColorParams, token: CancellationToken): ColorInformation[];
    onColorPresentations({ textDocument, color, range }: ColorPresentationParams, token: CancellationToken): import("vscode-languageserver-types").ColorPresentation[];
    onSignatureHelp({ textDocument, position }: TextDocumentPositionParams): SignatureHelp | null;
    /**
     * Validations
     */
    private triggerValidation;
    cleanPendingValidation(textDocument: TextDocument): void;
    validateTextDocument(textDocument: TextDocument): void;
    doValidate(doc: TextDocument): Diagnostic[];
    removeDocument(doc: TextDocument): void;
    dispose(): void;
    readonly capabilities: ServerCapabilities;
}
